import 'package:flutter/material.dart';
import 'package:flutter_html/flutter_html.dart';
import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:hqsoft_core/value_base/value_base.dart';
import 'package:html/dom.dart' as dom;

enum ConfirmActionTwoButton { CANCEL, ACCEPT }

enum ConfirmActionOneButton { CLOSE }

class AlertCustomize {
  AlertCustomize._();

  int indexRaBtn = 0;
  List<dynamic> selectedList = [];

  Future<void> showListDialog(
      BuildContext context,
      String title,
      bool search,
      bool isMultiChoice,
      String displayField,
      String valueField,
      List<dynamic> listData) {
    //  var currentClass = new Symbol(listData[0].toString());
    var currentClass = listData[0].toString();
    indexRaBtn = 0;
    TextEditingController _controller = TextEditingController();
    ValueNotifier<String> _valueFilter = ValueNotifier('');
    ValueNotifier<bool> _valueReload = ValueNotifier(false);

    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          title: Text(title),
          content: SingleChildScrollView(
            scrollDirection: Axis.vertical,
            child: Column(
              children: <Widget>[
                //Custom Search
                _searchBar(_controller, _valueFilter),

                //Content
                Container(
                  width: ScreenConfig.safeBlockHorizontal * 80,
                  height: ScreenConfig.safeBlockVertical * 50,
                  child: ListView(
                    scrollDirection: Axis.horizontal,
                    children: <Widget>[
                      Container(
                        width: ScreenConfig.safeBlockHorizontal * 120,
                        child: Column(
                          children: <Widget>[
                            //Customer Header
                            _header(currentClass, isMultiChoice),

                            //Custom Content
                            Expanded(
                              child: ListView(
                                scrollDirection: Axis.horizontal,
                                children: <Widget>[
                                  Container(
                                    //size width này sẽ = sum của các column header
                                    width:
                                        ScreenConfig.safeBlockHorizontal * 120,
                                    child: _listItems(
                                        listData,
                                        currentClass,
                                        _valueFilter,
                                        _valueReload,
                                        isMultiChoice),
                                  )
                                ],
                              ),
                            )
                          ],
                        ),
                      )
                    ],
                  ),
                )
              ],
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text('Cancel',
                  style: ThemeBase.textMessDialogButtonColorHint),
              onPressed: () {
                Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL);
              },
            ),
            TextButton(
              child:
                  Text('OK', style: ThemeBase.textMessDialogButtonColorPrimary),
              onPressed: () {
                if (isMultiChoice) {
                  selectedList = [];
                  if (currentClass == 'dataTemp') {
                    for (var item in listData) {
                      if ((item as DataTemp).isCheck) {
                        selectedList.add(item);
                      }
                    }
                  } else {}
                } else {
                  selectedList.add(listData[indexRaBtn]);
                }
                Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT);
              },
            ),
          ],
        );
      },
    );
  }

  Widget _listItems(
      List<dynamic> listData,
      String currentClass,
      ValueNotifier<String> _valueFilter,
      ValueNotifier<bool> _valueReload,
      bool isMultiChoice) {
    return ValueListenableBuilder(
        valueListenable: _valueFilter,
        builder: (context, value, _) {
          print('_listItems' + value.toString());

          List<dynamic> listFiltered = [];
          if (value.toString().length == 0) {
            listFiltered.addAll(listData);
          } else {
            switch (currentClass) {
              case 'dataTemp':
                listFiltered = listData
                    .where((i) =>
                        (i as DataTemp).value.contains(value.toString()) ||
                        (i).display.contains(value.toString()))
                    .toList();
                break;
              default:
                break;
            }
          }

          return ListView.builder(
              //shrinkWrap: true,
              itemCount: listFiltered.length,
              scrollDirection: Axis.vertical,
              itemBuilder: (context, index) {
                return InkWell(
                  onTap: () {
                    print('$index');
                    Calculator calculator =
                        new Calculator(onClickButton: (value) {
                      print('$value');
                    });
                    calculator.showCalculatorDialog(context, 'Nhập số lượng');
                  },
                  child: Container(
                    color:
                        index % 2 == 0 ? Colors.yellowAccent : Colors.redAccent,
                    child: _listContent(
                        index,
                        currentClass,
                        listFiltered[index],
                        _valueReload,
                        listData,
                        isMultiChoice),
                  ),
                );
              });
        });
  }

  Widget _searchBar(
      TextEditingController _controller, ValueNotifier<String> _valueFilter) {
    return new Container(
      height: 50.0,
      alignment: FractionalOffset.centerLeft,
      margin: const EdgeInsets.fromLTRB(0, 0, 0, 8),
      padding: const EdgeInsets.fromLTRB(8, 0, 8, 0),
      decoration: BoxDecoration(
          border: Border.all(color: HexColor("DCDCDC")),
          borderRadius: BorderRadius.circular(4.0)),
      child: Row(
        children: <Widget>[
          Icon(Icons.search),
          SizedBox(
            width: 8,
          ),
          Expanded(
              child: TextFormField(
            controller: _controller,
            style: new TextStyle(
                color: Colors.black, fontWeight: FontWeight.normal),
            autofocus: false,
            decoration: InputDecoration(
                border: InputBorder.none,
                hintText: 'Search...',
                hintStyle: new TextStyle(
                    color: Colors.grey, fontWeight: FontWeight.normal),
                suffixIcon: ValueListenableBuilder(
                    valueListenable: _valueFilter,
                    builder: (context, value, _) {
                      print(value.toString().length);
                      return IconButton(
                          icon: Icon(
                            Icons.cancel,
                            color: Colors.grey,
                            size: value.toString().length == 0 ? 0 : 20,
                          ),
                          onPressed: () {
                            _valueFilter.value = '';
                            _controller.clear();
                          });
                    })),
            onChanged: (text) {
              _valueFilter.value = text;
              print(text);
            },
          )),
        ],
      ),
    );
  }

  Widget _header(String nameClass, bool isMultiChoice) {
    switch (nameClass) {
      case 'dataTemp':
        return Container(
          height: 50.0,
          color: Colors.blueGrey[700],
          //padding: EdgeInsets.symmetric(horizontal: 0.0),
          alignment: Alignment.centerLeft,
          child: Row(
            children: <Widget>[
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 0),
                child: isMultiChoice == true
                    ? Checkbox(
                        value: true,
                        activeColor: Colors.redAccent,
                        onChanged: (value) {})
                    : Radio(value: 0, groupValue: 0, onChanged: (i) {}),
              ),
              Container(
                width: 1,
                color: Colors.white,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 8),
                child: Text('STT', style: const TextStyle(color: Colors.white)),
              ),
              Container(
                width: 1,
                color: Colors.white,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 8.0),
                child:
                    Text('Name', style: const TextStyle(color: Colors.white)),
              ),
              Container(
                width: 1,
                color: Colors.white,
              ),
              Padding(
                padding: const EdgeInsets.symmetric(horizontal: 8.0),
                child:
                    Text('Name', style: const TextStyle(color: Colors.white)),
              ),
            ],
          ),
        );
      default:
        return Container();
    }
  }

  Widget _listContent(
      int index,
      String nameClass,
      dynamic item,
      ValueNotifier<bool> _valueReload,
      List<dynamic> listParent,
      bool isMultiChoice) {
    return ValueListenableBuilder(
        valueListenable: _valueReload,
        builder: (context, value, _) {
          switch (nameClass) {
            case 'dataTemp':
              return Container(
                color: index % 2 == 0
                    ? Colors.white
                    : Colors.yellowAccent.withOpacity(0.5),
                //padding: EdgeInsets.all( 8.0),
                alignment: Alignment.centerLeft,
                child: Row(
                  children: <Widget>[
                    isMultiChoice == true
                        ? Checkbox(
                            value: (item as DataTemp).isCheck,
                            activeColor: Colors.redAccent,
                            onChanged: (value) {
                              (listParent[index] as DataTemp).isCheck = (value as bool);
                              _valueReload.value = !_valueReload.value;
                            })
                        : new Radio(
                            value: index,
                            groupValue: indexRaBtn,
                            onChanged: (i) {
                              print('radio : $i');
                              indexRaBtn = (i as int);
                              _valueReload.value = !_valueReload.value;
                            }),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 8.0),
                      padding: const EdgeInsets.symmetric(horizontal: 8.0),
                      child: Text('$index'),
                    ),
                    SizedBox(
                      width: 4,
                    ),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 8.0),
                      padding: const EdgeInsets.symmetric(horizontal: 8.0),
                      child: Text((item as DataTemp).display),
                    ),
                    SizedBox(
                      width: 4,
                    ),
                    Container(
                      margin: const EdgeInsets.symmetric(horizontal: 8.0),
                      padding: const EdgeInsets.symmetric(horizontal: 8.0),
                      child: Text((item).display),
                    ),
                  ],
                ),
              );
            default:
              return Container();
          }
        });
  }

  static Future<ConfirmActionOneButton?> showAlertDialogOneButton({
    Key key = const Key(''),
    required BuildContext context,
    String title = '',
    required String content,
    String typeBtn = '',
    bool isErrorNotify = true,
  }) async {
    await showDialog<ConfirmActionOneButton>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.all(Radius.circular(12)),
          ),
          titlePadding: const EdgeInsets.all(0.0),
          contentPadding: const EdgeInsets.all(0.0),
          buttonPadding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
          actionsPadding: const EdgeInsets.all(0.0),
          content: Container(
            padding: EdgeInsets.symmetric(
              vertical: ScreenConfig.getWidthPx(12),
            ),
            decoration: BoxDecoration(
              color: Colors.white,
              borderRadius: BorderRadius.all(Radius.circular(32)),
            ),
            child: SingleChildScrollView(
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.center,
                mainAxisSize: MainAxisSize.min,
                children: [
                  /// header
                  Row(
                    children: [
                      Expanded(child: Container()),
                      Container(
                        margin: EdgeInsets.only(
                          right: ScreenConfig.getWidthPx(8),
                        ),
                        width: ScreenConfig.getWidthPx(34),
                        height: ScreenConfig.getWidthPx(34),
                        child: IconButton(
                          padding: EdgeInsets.zero,
                          icon: Icon(
                            Icons.close_rounded,
                            color: colorPrimary,
                            size: 26,
                          ),
                          onPressed: () => Navigator.of(context).pop(ConfirmActionOneButton.CLOSE),
                        ),
                      ),
                    ],
                  ),

                  /// image
                  Container(
                    margin: EdgeInsets.only(
                      top: ScreenConfig.getWidthPx(5),
                      bottom: ScreenConfig.getWidthPx(25),
                    ),
                    child: ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(30)),
                      child: Image.asset(
                        isErrorNotify ? 'assets/images/img_notify_error.png' : 'assets/images/img_notify_success.png',
                        width: ScreenConfig.getWidthPx(65),
                        height: ScreenConfig.getWidthPx(65),
                      ),
                    ),
                  ),

                  /// content text
                  Container(
                    margin: EdgeInsets.only(
                      bottom: ScreenConfig.getWidthPx(28),
                      left: ScreenConfig.getWidthPx(20),
                      right: ScreenConfig.getWidthPx(20),
                    ),
                    child: Text(
                      content,
                      style: ThemeBase.textRobotoRegular16(color: colorTextFocus),
                      textAlign: TextAlign.center,
                    ),
                  ),
                ],
              ),
            ),
          ),
        );
      },
    );
  }

  static Future<void> showAlertDialogLoginViewNotify({
    Key key = const Key(''),
    required BuildContext context,
  }) async {
    return showDialog<void>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          titleTextStyle: ThemeBase.textWhiteMessDialogTitle,
          contentTextStyle: ThemeBase.textMessDialogContent,
          titlePadding: const EdgeInsets.all(0.0),
          contentPadding: const EdgeInsets.all(0.0),
          buttonPadding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
          actionsPadding: const EdgeInsets.all(0.0),
          title: Container(
            padding: const EdgeInsets.fromLTRB(5.0, 8.0, 5.0, 8.0),
            decoration: BoxDecoration(
              color: colorPrimary,
            ),
            child: Row(
              children: <Widget>[
                Icon(
                  Icons.info_outline,
                  size: ThemeBase.fontSize20,
                  color: colorWhite,
                ),
                SizedBox(width: 5),
                Text(allTranslations.text("sys_message")),
              ],
            ),
          ),
          content: SingleChildScrollView(
            child: Container(
              padding: const EdgeInsets.fromLTRB(10.0, 12.0, 10, 16.0),
              child: ListBody(
                children: <Widget>[
                  Text(allTranslations
                      .text("mess_push_notification_detail_login")),
                ],
              ),
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(
                allTranslations.text("sys_close"),
                style: ThemeBase.textMessDialogButtonColorPrimary,
              ),
              onPressed: () => Navigator.of(context).pop(),
            ),
          ],
        );
      },
    );
  }

  static Future<void> showAlertOneButtonClose({
    Key key = const Key(''),
    required BuildContext context,
    required var messages,
  }) async {
    ///Mess Service Error Socket
    if (Utils.isServiceErrorSocket(messages)) {
      await showAlertDialogOneButton(
          context: context,
          title: '',
          content: allTranslations.text('mess_network_failed'),
          typeBtn: allTranslations.text('sys_close'));
    }

    ///Mess Other
    else {
      await showAlertDialogOneButton(
          context: context,
          title: '',
          content: messages == ''
              ? allTranslations.text('mess_network_failed')
              : messages,
          typeBtn: allTranslations.text('sys_close'));
    }
  }

  static Future<void> showAlertOneButtonOK({
    Key key = const Key(''),
    required BuildContext context,
    required String messages,
  }) async {
    showAlertDialogOneButton(
        context: context,
        title: '',
        content: messages,
        typeBtn: allTranslations.text("sys_ok"));
  }

  static Future<void> showAlertTunOnNetwork({
    Key key = const Key(''),
    required BuildContext context,
    String? messages,
  }) async {
    showAlertDialogOneButton(
        context: context,
        title: '',
        content: messages ?? allTranslations.text("mess_network_invalid"),
        typeBtn: allTranslations.text("sys_close"));
  }

  static Future<ConfirmActionTwoButton?> showAlertDialogTwoButton({
    Key key = const Key(''),
    required BuildContext context,
    // Icons icons,
    String? title,
    required String content,
    String? typeBtnNo,
    String? typeBtnYes,
    String keyDialog = '',
    String keyBtnNo = '',
    String keyBtnYes = '',
  }) async {
    return await showDialog<ConfirmActionTwoButton?>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          key: Key(keyDialog),
          shape: RoundedRectangleBorder(
            borderRadius: BorderRadius.all(Radius.circular(12)),
          ),
          titlePadding: const EdgeInsets.all(0.0),
          contentPadding: const EdgeInsets.all(0.0),
          buttonPadding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
          actionsPadding: const EdgeInsets.all(0.0),
          content: SingleChildScrollView(
            child: Column(
              crossAxisAlignment: CrossAxisAlignment.start,
              children: [
                /// header
                Container(
                  width: double.infinity,
                  height: ScreenConfig.getWidthPx(48),
                  padding: EdgeInsets.only(
                    left: ScreenConfig.getWidthPx(15),
                  ),
                  alignment: Alignment.centerLeft,
                  decoration: BoxDecoration(
                    color: colorPrimary,
                    borderRadius: BorderRadius.only(
                      topLeft: Radius.circular(12),
                      topRight: Radius.circular(12),
                    ),
                  ),
                  child: Text(
                    title ?? allTranslations.text("sys_message"),
                    style: ThemeBase.textRobotoCustomize(
                      color: Colors.white,
                      fontWeight: FontWeight.w500,
                      fontSize: 16,
                    ),
                  ),
                ),

                /// text
                Container(
                  margin: EdgeInsets.only(
                    top: ScreenConfig.getWidthPx(10),
                    bottom: ScreenConfig.getWidthPx(25),
                    left: ScreenConfig.getWidthPx(20),
                    right: ScreenConfig.getWidthPx(20),
                  ),
                  child: Text(
                    content,
                    style: ThemeBase.textRobotoRegular16(color: colorTextFocus),
                    textAlign: TextAlign.center,
                  ),
                ),

                /// button
                Container(
                  margin: EdgeInsets.only(
                    bottom: ScreenConfig.getWidthPx(15),
                  ),
                  child: Row(
                    children: [
                      Expanded(
                        child: Container(
                          margin: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(15),
                            right: ScreenConfig.getWidthPx(10),
                          ),
                          child: RawMaterialButton(
                            fillColor: Colors.white,
                            padding: EdgeInsets.symmetric(vertical: ScreenConfig.getWidthPx(10)),
                            onPressed: () => Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL),
                            shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.all(Radius.circular(12)),
                              side: BorderSide(color: colorPrimary),
                            ),
                            child: Center(
                              child: Text(
                                typeBtnNo ?? allTranslations.text("sys_no"),
                                style: ThemeBase.textRobotoRegular16(color: colorPrimary),
                              ),
                            ),
                          ),
                        ),
                      ),
                      Expanded(
                        child: Container(
                          margin: EdgeInsets.only(
                            left: ScreenConfig.getWidthPx(10),
                            right: ScreenConfig.getWidthPx(15),
                          ),
                          child: RawMaterialButton(
                            fillColor: colorPrimary,
                            padding: EdgeInsets.symmetric(vertical: ScreenConfig.getWidthPx(10)),
                            onPressed: () => Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT),
                            shape: RoundedRectangleBorder(
                              borderRadius: BorderRadius.all(Radius.circular(12)),
                              side: BorderSide(color: colorPrimary),
                            ),
                            child: Center(
                              child: Text(
                                typeBtnYes ?? allTranslations.text("sys_yes"),
                                style: ThemeBase.textRobotoRegular16(color: Colors.white),
                              ),
                            ),
                          ),
                        ),
                      )
                    ],
                  ),
                ),
              ],
            ),
          ),
        );
      },
    );
  }

  static Future<ConfirmActionTwoButton?> showAlertDialogTwoButtonBox({
    Key key = const Key(''),
    required BuildContext context,
    // required IconData icons,
    required String title,
    required String content,
    String? typeBtnNo,
    String? typeBtnYes,
  }) async {
    return await showDialog<ConfirmActionTwoButton?>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          titleTextStyle: ThemeBase.textWhiteMessDialogTitle,
          contentTextStyle: ThemeBase.textMessDialogContent,
          titlePadding: const EdgeInsets.all(0.0),
          contentPadding: const EdgeInsets.all(0.0),
          buttonPadding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
          actionsPadding: const EdgeInsets.all(0.0),
          title: Container(
            padding: const EdgeInsets.fromLTRB(5.0, 8.0, 5.0, 8.0),
            decoration: BoxDecoration(
              color: colorPrimary,
            ),
            child: Row(
              children: <Widget>[
                Icon(
                  Icons.info_outline,
                  size: ThemeBase.fontSize20,
                  color: colorWhite,
                ),
                SizedBox(width: 5),
                Text(title),
                // allTranslations.text("sys_message")
              ],
            ),
          ),
          content: SingleChildScrollView(
            child: Container(
              margin: const EdgeInsets.fromLTRB(10.0, 10.0, 10.0, 0.0),
              alignment: Alignment.center,
              decoration: BoxDecoration(
                color: Colors.grey.shade100,
                border: Border.all(color: Colors.grey.shade300, width: 1.0),
              ),
              child: ListBody(
                children: <Widget>[
                  Html(
                    data: content,
                    onLinkTap: (String? url, RenderContext context, Map<String, String> attributes,  dom.Element? element) {
                      print("Opening $url...");
                    },
                  ),
                ],
              ),
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(
                typeBtnNo ?? allTranslations.text("sys_no"),
                style: ThemeBase.textMessDialogButtonColorHint,
              ),
              onPressed: () =>
                  Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL),
            ),
            TextButton(
              child: Text(
                typeBtnYes ?? allTranslations.text("sys_yes"),
                style: ThemeBase.textMessDialogButtonColorPrimary,
              ),
              onPressed: () =>
                  Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT),
            ),
          ],
        );
      },
    );
  }

  static Future<AlertCustomizeTwoButtonResults?>
      showAlertDialogTwoButtonInputText({
    Key key = const Key(''),
    required BuildContext context,
    required String title,
    required String content,
    required String hintInputText,
    String? typeBtnNo,
    String? typeBtnYes,
    String keyDialog = '',
    String keyBtnNo = '',
    String keyBtnYes = '',
  }) async {
    TextEditingController _inputTextController = TextEditingController();
    return await showDialog<AlertCustomizeTwoButtonResults?>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          key: Key(keyDialog),
          titleTextStyle: ThemeBase.textWhiteMessDialogTitle,
          contentTextStyle: ThemeBase.textMessDialogContent,
          titlePadding: const EdgeInsets.all(0.0),
          contentPadding: const EdgeInsets.all(0.0),
          buttonPadding: const EdgeInsets.fromLTRB(0.0, 0.0, 10.0, 0.0),
          actionsPadding: const EdgeInsets.all(0.0),
          title: Container(
            padding: const EdgeInsets.fromLTRB(5.0, 8.0, 5.0, 8.0),
            decoration: BoxDecoration(
              color: colorPrimary,
            ),
            child: Row(
              children: <Widget>[
                Icon(
                  Icons.info_outline,
                  size: ThemeBase.fontSize20,
                  color: colorWhite,
                ),
                SizedBox(width: 5),
                Text(title),
                // allTranslations.text("sys_message")
              ],
            ),
          ),
          content: SingleChildScrollView(
            child: Container(
              padding: const EdgeInsets.fromLTRB(10.0, 12.0, 10, 16.0),
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  Text(content),
                  Container(
                    padding: EdgeInsets.only(top: ScreenConfig.getWidthPx(10)),
                    child: Row(
                      crossAxisAlignment: CrossAxisAlignment.center,
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        Expanded(
                          child: Container(
                            padding: EdgeInsets.all(ScreenConfig.getWidthPx(0)),
                            alignment: Alignment.center,
                            height: ScreenConfig.getWidthPx(40),
                            decoration: BoxDecoration(
                                color: Colors.grey.shade100,
                                border: Border.all(
                                    color: Colors.grey.shade400, width: 1.0),
                                borderRadius: BorderRadius.circular(2.0)),
                            child: TextFormField(
                              style: ThemeBase.textBoxFieldBlack,
                              obscureText: false,
                              controller: _inputTextController,
                              textInputAction: TextInputAction.next,
                              keyboardType: TextInputType.text,
                              decoration: InputDecoration(
                                contentPadding: const EdgeInsets.all(12),
                                fillColor: Colors.red,
                                border: InputBorder.none,
                                hintText: hintInputText,
                                // allTranslations.text("alert_customize_input_code_hint")
                                hintStyle: ThemeBase.textBoxFieldHint,
                              ),
                            ),
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          ),
          actions: <Widget>[
            TextButton(
              key: Key(keyBtnNo),
              child: Text(
                typeBtnNo ?? allTranslations.text("sys_no"),
                style: ThemeBase.textMessDialogButtonColorHint,
              ),
              onPressed: () {
                Navigator.of(context).pop(
                  AlertCustomizeTwoButtonResults(
                    confirmAction: ConfirmActionTwoButton.CANCEL,
                    result: '',
                  ),
                );
              },
            ),
            TextButton(
              key: Key(keyBtnYes),
              child: Text(
                typeBtnYes ?? allTranslations.text("sys_yes"),
                style: ThemeBase.textMessDialogButtonColorPrimary,
              ),
              onPressed: () {
                Navigator.of(context).pop(
                  AlertCustomizeTwoButtonResults(
                    confirmAction: ConfirmActionTwoButton.ACCEPT,
                    result: _inputTextController.text,
                  ),
                );
              },
            ),
          ],
        );
      },
    );
  }

  static Future<ConfirmActionOneButton?> showAlertDialogOneButtonNoTitle({
    Key key = const Key(''),
    required BuildContext context,
    required String content,
    String? typeBtn,
  }) async {
    return await showDialog<ConfirmActionOneButton?>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          content: SingleChildScrollView(
            child: ListBody(
              children: <Widget>[
                Text(content ),
              ],
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(
                typeBtn ?? allTranslations.text("sys_close"),
                style: ThemeBase.textMessDialogButtonColorPrimary,
              ),
              onPressed: () =>
                  Navigator.of(context).pop(ConfirmActionOneButton.CLOSE),
            ),
          ],
        );
      },
    );
  }

  static Future<ConfirmActionTwoButton?> showAlertDialogTwoButtonNoTitle({
    Key key = const Key(''),
    required BuildContext context,
    required String content,
    String? typeBtnNo,
    String? typeBtnYes,
  }) async {
    return await showDialog<ConfirmActionTwoButton?>(
      context: context,
      barrierDismissible: false, // user must tap button!
      builder: (BuildContext context) {
        return AlertDialog(
          content: SingleChildScrollView(
            child: ListBody(
              children: <Widget>[
                Text(content),
              ],
            ),
          ),
          actions: <Widget>[
            TextButton(
              child: Text(
                typeBtnNo ?? allTranslations.text("sys_no"),
                style: ThemeBase.textMessDialogButtonColorHint,
              ),
              onPressed: () =>
                  Navigator.of(context).pop(ConfirmActionTwoButton.CANCEL),
            ),
            TextButton(
              child: Text(
                typeBtnYes ?? allTranslations.text("sys_yes"),
                style: ThemeBase.textMessDialogButtonColorPrimary,
              ),
              onPressed: () =>
                  Navigator.of(context).pop(ConfirmActionTwoButton.ACCEPT),
            ),
          ],
        );
      },
    );
  }
}

//class example
class DataTemp {
  String display;
  String value;
  bool isCheck = false;


  DataTemp({this.display = '', this.value = '', this.isCheck = false});

  @override
  String toString() => '$runtimeType';

  dataTemp(String display, String value) {
    this.display = display;
    this.value = value;
  }

  String getDisplayValue() {
    return display;
  }

  String getKeyValue() {
    return value;
  }
}
